@@ -60,7 +60,8 @@ Minion::Backend - Backend base class
 
 =head1 DESCRIPTION
 
-L<Minion::Backend> is an abstract base class for L<Minion> backends.
+L<Minion::Backend> is an abstract base class for L<Minion> backends, like
+L<Minion::Backend::Pg>.
 
 =head1 ATTRIBUTES
 
@@ -165,7 +166,7 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job($job_id, $retries);
   my $bool = $backend->fail_job($job_id, $retries, 'Something went wrong!');
   my $bool = $backend->fail_job(
-    $job_id, $retries, {msg => 'Something went wrong!'});
+    $job_id, $retries, {whatever => 'Something went wrong!'});
 
 Transition from C<active> to C<failed> state. Meant to be overloaded in a
 subclass.
@@ -174,7 +175,8 @@ subclass.
 
   my $bool = $backend->finish_job($job_id, $retries);
   my $bool = $backend->finish_job($job_id, $retries, 'All went well!');
-  my $bool = $backend->finish_job($job_id, $retries, {msg => 'All went well!'});
+  my $bool = $backend->finish_job(
+    $job_id, $retries, {whatever => 'All went well!'});
 
 Transition from C<active> to C<finished> state. Meant to be overloaded in a
 subclass.
