@@ -190,7 +190,7 @@ sub _try {
      set started = now(), state = 'active', worker = ?
      where id = (
        select id from minion_jobs
-       where delayed < now() and queue = any (?) and state = 'inactive'
+       where delayed <= now() and queue = any (?) and state = 'inactive'
          and task = any (?)
        order by priority desc, created
        limit 1
@@ -338,7 +338,7 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job($job_id, $retries);
   my $bool = $backend->fail_job($job_id, $retries, 'Something went wrong!');
   my $bool = $backend->fail_job(
-    $job_id, $retries, {msg => 'Something went wrong!'});
+    $job_id, $retries, {whatever => 'Something went wrong!'});
 
 Transition from C<active> to C<failed> state.
 
@@ -346,7 +346,8 @@ Transition from C<active> to C<failed> state.
 
   my $bool = $backend->finish_job($job_id, $retries);
   my $bool = $backend->finish_job($job_id, $retries, 'All went well!');
-  my $bool = $backend->finish_job($job_id, $retries, {msg => 'All went well!'});
+  my $bool = $backend->finish_job(
+    $job_id, $retries, {whatever => 'All went well!'});
 
 Transition from C<active> to C<finished> state.
 
